#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 logging-facade
version:              0.3.0
visibility:           public
id:                   logging-facade-0.3.0-5OhXVyL68KEB1f15UMzCOf
key:                  logging-facade-0.3.0-5OhXVyL68KEB1f15UMzCOf
license:              MIT
copyright:            (c) 2014-2017 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/logging-facade#readme
synopsis:             Simple logging abstraction that allows multiple back-ends
description:          Simple logging abstraction that allows multiple back-ends
category:             System
abi:                  1fcf093dac4d26b6a100db8263adeaad
exposed:              True
exposed-modules:
    System.Logging.Facade System.Logging.Facade.Class
    System.Logging.Facade.Sink System.Logging.Facade.Types

hidden-modules:       Paths_logging_facade
import-dirs:          /usr/lib/ghc-8.10.5/site-local/logging-facade-0.3.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/logging-facade-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/logging-facade-0.3.0
hs-libraries:         HSlogging-facade-0.3.0-5OhXVyL68KEB1f15UMzCOf
depends:
    base-4.14.2.0 call-stack-0.3.0-HaJG5jRa2XM74od97nDj56
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-logging-facade/html/logging-facade.haddock

haddock-html:         /usr/share/doc/haskell-logging-facade/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

